@@ -128,7 +128,7 @@ def main(tbuf=None, **kwargs):
     # instantiate TB
     # if tbuf is None:
     from pandaserver.taskbuffer.TaskBuffer import taskBuffer
-    taskBuffer.init(panda_config.dbhost,panda_config.dbpasswd,nDBConnection=1)
+    taskBuffer.init(panda_config.dbhost,panda_config.dbpasswd,nDBConnection=1, useTimeout=True)
     # else:
     #     taskBuffer = tbuf
 
