@@ -558,22 +558,6 @@ class UserIF:
         return WrappedPickle.dumps(siteMapper.cloudSpec)
 
 
-    # get list of cache prefix
-    def getCachePrefixes(self):
-        # get
-        ret = self.taskBuffer.getCachePrefixes()
-        # serialize
-        return WrappedPickle.dumps(ret)
-
-
-    # get list of cmtConfig
-    def getCmtConfigList(self,relaseVer):
-        # get
-        ret = self.taskBuffer.getCmtConfigList(relaseVer)
-        # serialize
-        return WrappedPickle.dumps(ret)
-
-
     # get nPilots
     def getNumPilots(self):
         # get nPilots
@@ -1483,13 +1467,6 @@ def getSiteSpecs(req,siteType=None):
 def getCloudSpecs(req):
     return userIF.getCloudSpecs()
 
-# get list of cache prefix
-def getCachePrefixes(req):
-    return userIF.getCachePrefixes()
-
-# get list of cmtConfig
-def getCmtConfigList(self,relaseVer):
-    return userIF.getCmtConfigList(relaseVer)
 
 # get ban users
 def get_ban_users(req):
@@ -2130,7 +2107,7 @@ def changeTaskSplitRulePanda(req,jediTaskID,attrName,attrValue):
     except Exception:
         return WrappedPickle.dumps((False,'jediTaskID must be an integer'))
     # check attribute
-    if attrName not in ['TW','EC','ES','MF','NG','NI','NF','NJ', 'AV', 'IL', 'LI', 'LC', 'CC']:
+    if attrName not in ['TW', 'EC', 'ES', 'MF', 'NG', 'NI', 'NF', 'NJ', 'AV', 'IL', 'LI', 'LC', 'CC', 'OT']:
         return WrappedPickle.dumps((2,"disallowed to update {0}".format(attrName)))
     ret = userIF.changeTaskSplitRulePanda(jediTaskID,attrName,attrValue)
     return WrappedPickle.dumps((ret,None))
@@ -2616,11 +2593,10 @@ def relay_idds_command(req, command_name, args=None, kwargs=None, manager=None):
                 kwargs = json.loads(kwargs, object_hook=decode_idds_enum)
         else:
             kwargs = {}
-        # set user name
-        if manager and command_name in ['submit']:
-            dn = req.subprocess_env.get('SSL_CLIENT_S_DN')
-            if dn:
-                kwargs['username'] = clean_user_id(dn)
+        # set original username
+        dn = req.subprocess_env.get('SSL_CLIENT_S_DN')
+        if dn:
+            c.set_original_user(user_name=clean_user_id(dn))
         tmpLog.debug("execute: class={} com={} host={} args={} kwargs={}".format(
             c.__class__.__name__, command_name, idds_host, str(args)[:200], str(kwargs)[:200]))
         ret = getattr(c, command_name)(*args, **kwargs)
@@ -2638,7 +2614,7 @@ def relay_idds_command(req, command_name, args=None, kwargs=None, manager=None):
 # relay iDDS workflow command with ownership check
 def execute_idds_workflow_command(req, command_name, kwargs=None):
     try:
-        tmpLog = LogWrapper(_logger, 'relay_idds_user_command-{}'.format(datetime.datetime.utcnow().isoformat('/')))
+        tmpLog = LogWrapper(_logger, 'execute_idds_workflow_command-{}'.format(datetime.datetime.utcnow().isoformat('/')))
         if kwargs:
             try:
                 kwargs = idds.common.utils.json_loads(kwargs)
@@ -2661,9 +2637,9 @@ def execute_idds_workflow_command(req, command_name, kwargs=None):
             return json.dumps((False, tmpMsg))
         # check owner
         c = iDDS_ClientManager(idds_host)
+        dn = req.subprocess_env.get('SSL_CLIENT_S_DN')
         if check_owner:
             # requester
-            dn = req.subprocess_env.get('SSL_CLIENT_S_DN')
             if not dn:
                 tmpMsg = 'SSL_CLIENT_S_DN is missing in HTTP request'
                 tmpLog.error(tmpMsg)
@@ -2680,15 +2656,21 @@ def execute_idds_workflow_command(req, command_name, kwargs=None):
             if not req:
                 tmpMsg = 'request {} is not found'.format(request_id)
                 tmpLog.error(tmpMsg)
-                return json.dumps((False, ))
+                return json.dumps((False, tmpMsg))
             user_name = req[0].get('username')
             if user_name and user_name != requester:
                 tmpMsg = 'request {} is not owned by {}'.format(request_id, requester)
                 tmpLog.error(tmpMsg)
                 return json.dumps((False, tmpMsg))
+        # set original username
+        if dn:
+            c.set_original_user(user_name=clean_user_id(dn))
         # execute command
         tmpLog.debug('com={} host={} kwargs={}'.format(command_name, idds_host, str(kwargs)))
         ret = getattr(c, command_name)(**kwargs)
+        tmpLog.debug(str(ret))
+        if isinstance(ret, dict) and 'message' in ret:
+            return json.dumps((True, [ret['status'], ret['message']]))
         return json.dumps((True, ret))
     except Exception as e:
         tmpLog.error('failed with {} {}'.format(str(e), traceback.format_exc()))
