@@ -87,6 +87,14 @@ class Node (object):
 
     # set real input values
     def set_input_value(self, key, src_key, src_value):
+        # replace the value with a list of parameter names and indexes if value is a list,
+        # and src and dst are looping params
+        if isinstance(src_value, list):
+            src_loop_param_name = self.get_loop_param_name(src_key)
+            loop_params = self.get_loop_param_name(key.split('/')[-1]) is not None and src_loop_param_name is not None
+            if loop_params:
+                src_value = [{'src': src_loop_param_name, 'idx': i} for i in range(len(src_value))]
+        # resolve values
         if isinstance(self.inputs[key]['source'], list):
             self.inputs[key].setdefault('value', copy.copy(self.inputs[key]['source']))
             tmp_list = []
@@ -280,10 +288,12 @@ class Node (object):
                 else:
                     list_in_ds = ['{}_{}/'.format(dict_inputs['opt_inDS'], in_ds_suffix) if in_ds_suffix \
                                       else dict_inputs['opt_inDS']]
-                if self.type not in ['junction', 'reana']:
+                if self.type not in ['reana']:
                     in_ds_str = ','.join(list_in_ds)
                     com += ['--inDS', in_ds_str, '--notExpandInDS', '--notExpandSecDSs']
-                else:
+                    if self.type in ['junction']:
+                        com += ['--forceStaged', '--forceStagedSecondary']
+                if self.type in ['junction', 'reana']:
                     # replace placeholders in opt_exec and opt_args
                     for idx, dst in enumerate(list_in_ds):
                         src = "%{{DS{}}}".format(idx)
@@ -445,11 +455,11 @@ class Node (object):
         loop_params = {}
         workflow_params = {}
         for k, v in six.iteritems(root_inputs):
-            param = k.split('#')[-1]
-            m = re.search(r'^param_(.+)', param)
+            m = self.get_loop_param_name(k)
             if m:
-                loop_params[m.group(1)] = v
+                loop_params[m] = v
             else:
+                param = k.split('#')[-1]
                 workflow_params[param] = v
         return loop_params, workflow_params
 
@@ -464,6 +474,14 @@ class Node (object):
                 sub_node.get_all_sub_node_ids(all_ids)
         return all_ids
 
+    # get loop param name
+    def get_loop_param_name(self, k):
+        param = k.split('#')[-1]
+        m = re.search(r'^param_(.+)', param)
+        if m:
+            return m.group(1)
+        return None
+
 
 # dump nodes
 def dump_nodes(node_list, dump_str=None, only_leaves=False):
@@ -597,7 +615,10 @@ def convert_nodes_to_workflow(nodes, workflow_node=None, workflow=None):
             if node.loop:
                 for sub_node in node.sub_nodes:
                     if sub_node.type == 'junction':
-                        cond = Condition(cond=sub_id_work_map[sub_node.id].get_not_custom_condition_status)
+                        # use to_continue for loop termination
+                        j_work = sub_id_work_map[sub_node.id]
+                        j_work.add_custom_condition(key='to_continue', value=True)
+                        cond = Condition(cond=j_work.get_custom_condition_status)
                         sub_workflow.add_loop_condition(cond)
                         cond_dump_str += '    Loop in ID:{} with terminator ID:{}\n'.format(node.id, sub_node.id)
                         break
@@ -719,11 +740,24 @@ def convert_nodes_to_workflow(nodes, workflow_node=None, workflow=None):
     if workflow_node:
         tmp_global, tmp_workflow_global = workflow_node.get_global_parameters()
         if tmp_global:
-            workflow.set_global_parameters({'user_' + k: tmp_global[k] for k in tmp_global})
-            cond_dump_str += '\n  Looping Globals\n'
+            loop_locals = {}
+            loop_slices = []
+            for k, v in six.iteritems(tmp_global):
+                if not isinstance(v, dict):
+                    # normal looping locals
+                    loop_locals['user_' + k] = tmp_global[k]
+                else:
+                    # sliced locals
+                    v['src'] = 'user_' + v['src']
+                    loop_slices.append([k, v])
+            if loop_locals:
+                workflow.set_global_parameters(loop_locals)
+            for k, v in loop_slices:
+                workflow.set_sliced_global_parameters(source=v['src'], index=v['idx'], name='user_'+k)
+            cond_dump_str += '\n  Looping local variables\n'
             cond_dump_str += '    {}\n'.format(tmp_global)
         if tmp_workflow_global:
-            cond_dump_str += '\n  Workflow Globals\n'
+            cond_dump_str += '\n  Workflow local variable\n'
             cond_dump_str += '    {}\n'.format(tmp_workflow_global)
     # dump strings
     dump_str_list.insert(0, class_dump_str+'\n'+cond_dump_str+'\n\n')
